==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel.md <==
# AwsIoTAnalyticsChannel


```text
aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel
```

```text
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')
```



| Illustration | AwsIoTAnalyticsChannel | AwsIoTAnalyticsChannelCard | AwsIoTAnalyticsChannelGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel.png) | ![illustration for AwsIoTAnalyticsChannel](../../../aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel.Local.png) | ![illustration for AwsIoTAnalyticsChannelCard](../../../aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannelCard.Local.png) | ![illustration for AwsIoTAnalyticsChannelGroup](../../../aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannelGroup.Local.png) |




## AwsIoTAnalyticsChannel

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsChannel
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')

' renders the element
AwsIoTAnalyticsChannel('AwsIoTAnalyticsChannel', 'Aws Io T Analytics Channel', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsChannel
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')

' renders the element
AwsIoTAnalyticsChannel('AwsIoTAnalyticsChannel', 'Aws Io T Analytics Channel', 'an optional tech label')
@enduml
```

## AwsIoTAnalyticsChannelCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsChannelCard
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')

' renders the element
AwsIoTAnalyticsChannelCard('AwsIoTAnalyticsChannelCard', 'Aws Io T Analytics Channel Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsChannelCard
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')

' renders the element
AwsIoTAnalyticsChannelCard('AwsIoTAnalyticsChannelCard', 'Aws Io T Analytics Channel Card', 'an optional description')
@enduml
```

## AwsIoTAnalyticsChannelGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsChannelGroup
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')

' renders the element
AwsIoTAnalyticsChannelGroup('AwsIoTAnalyticsChannelGroup', 'Aws Io T Analytics Channel Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsChannelGroup
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')

' renders the element
AwsIoTAnalyticsChannelGroup('AwsIoTAnalyticsChannelGroup', 'Aws Io T Analytics Channel Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel.md <==
# AwsIoTAnalyticsChannel


```text
aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel
```

```text
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')
```



| Illustration | AwsIoTAnalyticsChannel | AwsIoTAnalyticsChannelCard | AwsIoTAnalyticsChannelGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel.png) | ![illustration for AwsIoTAnalyticsChannel](../../../aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel.Local.png) | ![illustration for AwsIoTAnalyticsChannelCard](../../../aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannelCard.Local.png) | ![illustration for AwsIoTAnalyticsChannelGroup](../../../aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannelGroup.Local.png) |




## AwsIoTAnalyticsChannel

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsChannel
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')

' renders the element
AwsIoTAnalyticsChannel('AwsIoTAnalyticsChannel', 'Aws Io T Analytics Channel', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsChannel
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')

' renders the element
AwsIoTAnalyticsChannel('AwsIoTAnalyticsChannel', 'Aws Io T Analytics Channel', 'an optional tech label')
@enduml
```

## AwsIoTAnalyticsChannelCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsChannelCard
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')

' renders the element
AwsIoTAnalyticsChannelCard('AwsIoTAnalyticsChannelCard', 'Aws Io T Analytics Channel Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsChannelCard
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')

' renders the element
AwsIoTAnalyticsChannelCard('AwsIoTAnalyticsChannelCard', 'Aws Io T Analytics Channel Card', 'an optional description')
@enduml
```

## AwsIoTAnalyticsChannelGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsChannelGroup
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')

' renders the element
AwsIoTAnalyticsChannelGroup('AwsIoTAnalyticsChannelGroup', 'Aws Io T Analytics Channel Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsChannelGroup
include('aws-q3-2021/Resource/LoT/AwsIoTAnalyticsChannel')

' renders the element
AwsIoTAnalyticsChannelGroup('AwsIoTAnalyticsChannelGroup', 'Aws Io T Analytics Channel Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
